"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var static_1 = require("../static");
var transport_info_1 = require("./transport-info");
var transport_1 = require("./transport");
var renderer_transport_1 = require("./renderer-transport");
var ProcessingMode;
(function (ProcessingMode) {
    ProcessingMode[ProcessingMode["ResolveOnly"] = 0] = "ResolveOnly";
    ProcessingMode[ProcessingMode["ResolveAndCollect"] = 1] = "ResolveAndCollect";
})(ProcessingMode = exports.ProcessingMode || (exports.ProcessingMode = {}));
var Bundle = /** @class */ (function () {
    function Bundle(url, path) {
        this.url = url;
        this.repack = true;
        this.imports = [];
        this.path = path || this.url;
    }
    Bundle.prototype.includes = function (info) { return this.imports.some(function (i) { return i === info || i.hash === info.hash; }); };
    Bundle.prototype.add = function (info) {
        this.imports.push(info);
        this.repack = true;
        return this;
    };
    Bundle.prototype.collect = function () {
        var _this = this;
        var comps = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            comps[_i] = arguments[_i];
        }
        comps.forEach(function (comp) {
            var info = transport_1.getCompTransportInfo(comp);
            if (info && !_this.includes(info))
                _this.add(info);
        });
        return comps.length == 0 ? this.process(ProcessingMode.ResolveAndCollect) : this;
    };
    Bundle.prototype.resolve = function () { return this.process(ProcessingMode.ResolveOnly); };
    Bundle.prototype.process = function (mode) {
        var _this = this;
        var renderer = new static_1.StaticRenderer();
        return function (document) {
            renderer.render(renderer.create("script", { src: _this.url })).on(document.head);
            transport_info_1.fetchInfo(document).forEach(function (info) {
                if (!info.resolved) {
                    if (_this.includes(info))
                        info.resolved = true;
                    else if (mode === ProcessingMode.ResolveAndCollect) {
                        _this.add(info);
                        info.resolved = true;
                    }
                }
            });
        };
    };
    Bundle.prototype.withRenderer = function (factory) {
        this.rendererImport = renderer_transport_1.getRendererTransportInfo(factory) || this.rendererImport;
        return this;
    };
    return Bundle;
}());
exports.Bundle = Bundle;
//# sourceMappingURL=bundle.js.map