import { StaticRenderer } from '../static';
import { fetchInfo } from './transport-info';
import { getCompTransportInfo } from './transport';
import { getRendererTransportInfo } from './renderer-transport';
export var ProcessingMode;
(function (ProcessingMode) {
    ProcessingMode[ProcessingMode["ResolveOnly"] = 0] = "ResolveOnly";
    ProcessingMode[ProcessingMode["ResolveAndCollect"] = 1] = "ResolveAndCollect";
})(ProcessingMode || (ProcessingMode = {}));
export class Bundle {
    constructor(url, path) {
        this.url = url;
        this.repack = true;
        this.imports = [];
        this.path = path || this.url;
    }
    includes(info) { return this.imports.some(i => i === info || i.hash === info.hash); }
    add(info) {
        this.imports.push(info);
        this.repack = true;
        return this;
    }
    collect(...comps) {
        comps.forEach(comp => {
            const info = getCompTransportInfo(comp);
            if (info && !this.includes(info))
                this.add(info);
        });
        return comps.length == 0 ? this.process(ProcessingMode.ResolveAndCollect) : this;
    }
    resolve() { return this.process(ProcessingMode.ResolveOnly); }
    process(mode) {
        const renderer = new StaticRenderer();
        return (document) => {
            renderer.render(renderer.create("script", { src: this.url })).on(document.head);
            fetchInfo(document).forEach(info => {
                if (!info.resolved) {
                    if (this.includes(info))
                        info.resolved = true;
                    else if (mode === ProcessingMode.ResolveAndCollect) {
                        this.add(info);
                        info.resolved = true;
                    }
                }
            });
        };
    }
    withRenderer(factory) {
        this.rendererImport = getRendererTransportInfo(factory) || this.rendererImport;
        return this;
    }
}
//# sourceMappingURL=bundle.js.map